package com.ruoyi.project.production.mapper;

import java.util.List;
import com.ruoyi.framework.aspectj.lang.annotation.DataScope;
import com.ruoyi.project.production.domain.TSaiCategory;

/**
 * SAI类别Mapper接口
 * 
 * @author ruoyi
 * @date 2023-04-18
 */
public interface TSaiCategoryMapper 
{
    /**
     * 查询SAI类别
     * 
     * @param saiCategoryId SAI类别ID
     * @return SAI类别
     */
    public TSaiCategory selectTSaiCategoryById(Long saiCategoryId);

    /**
     * 查询SAI类别列表
     * 
     * @param tSaiCategory SAI类别
     * @return SAI类别集合
     */
    @DataScope(deptAlias = "d")
    public List<TSaiCategory> selectTSaiCategoryList(TSaiCategory tSaiCategory);

    /**
     * 新增SAI类别
     * 
     * @param tSaiCategory SAI类别
     * @return 结果
     */
    public int insertTSaiCategory(TSaiCategory tSaiCategory);

    /**
     * 修改SAI类别
     * 
     * @param tSaiCategory SAI类别
     * @return 结果
     */
    public int updateTSaiCategory(TSaiCategory tSaiCategory);

    /**
     * 删除SAI类别
     * 
     * @param saiCategoryId SAI类别ID
     * @return 结果
     */
    public int deleteTSaiCategoryById(Long saiCategoryId);

    /**
     * 批量删除SAI类别
     * 
     * @param saiCategoryIds 需要删除的数据ID
     * @return 结果
     */
    public int deleteTSaiCategoryByIds(Long[] saiCategoryIds);
}
